@@ -9,8 +9,6 @@
 ## See ll/__init__.py for the license
 
 
-import warnings
-
 from ll.xist import xsc
 from ll.xist.ns import doc
 
@@ -22,4 +20,4 @@ def test_explain():
 	"""
 	This is <func>test_explain</func>.
 	"""
-	assert unicode(doc.explain(test_explain, format="xist").walknode(doc.func)[0]) == u"test_explain"
+	assert unicode(doc.explain(test_explain, format="xist").walknodes(doc.func)[0]) == u"test_explain"
